# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import get_account_info_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_get__account__info__pb2
from . import get_account_transaction_history_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_get__account__transaction__history__pb2
from . import get_fee_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_get__fee__pb2
from . import get_ledger_data_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_get__ledger__data__pb2
from . import get_ledger_diff_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_get__ledger__diff__pb2
from . import get_ledger_entry_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_get__ledger__entry__pb2
from . import get_ledger_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_get__ledger__pb2
from . import get_transaction_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_get__transaction__pb2
from . import submit_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_submit__pb2


class XRPLedgerAPIServiceStub(object):
    """RPCs available to interact with the XRP Ledger.
    The gRPC API mimics the JSON API. Refer to xrpl.org for documentation
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetAccountInfo = channel.unary_unary(
                '/org.xrpl.rpc.v1.XRPLedgerAPIService/GetAccountInfo',
                request_serializer=org_dot_xrpl_dot_rpc_dot_v1_dot_get__account__info__pb2.GetAccountInfoRequest.SerializeToString,
                response_deserializer=org_dot_xrpl_dot_rpc_dot_v1_dot_get__account__info__pb2.GetAccountInfoResponse.FromString,
                )
        self.GetFee = channel.unary_unary(
                '/org.xrpl.rpc.v1.XRPLedgerAPIService/GetFee',
                request_serializer=org_dot_xrpl_dot_rpc_dot_v1_dot_get__fee__pb2.GetFeeRequest.SerializeToString,
                response_deserializer=org_dot_xrpl_dot_rpc_dot_v1_dot_get__fee__pb2.GetFeeResponse.FromString,
                )
        self.SubmitTransaction = channel.unary_unary(
                '/org.xrpl.rpc.v1.XRPLedgerAPIService/SubmitTransaction',
                request_serializer=org_dot_xrpl_dot_rpc_dot_v1_dot_submit__pb2.SubmitTransactionRequest.SerializeToString,
                response_deserializer=org_dot_xrpl_dot_rpc_dot_v1_dot_submit__pb2.SubmitTransactionResponse.FromString,
                )
        self.GetTransaction = channel.unary_unary(
                '/org.xrpl.rpc.v1.XRPLedgerAPIService/GetTransaction',
                request_serializer=org_dot_xrpl_dot_rpc_dot_v1_dot_get__transaction__pb2.GetTransactionRequest.SerializeToString,
                response_deserializer=org_dot_xrpl_dot_rpc_dot_v1_dot_get__transaction__pb2.GetTransactionResponse.FromString,
                )
        self.GetAccountTransactionHistory = channel.unary_unary(
                '/org.xrpl.rpc.v1.XRPLedgerAPIService/GetAccountTransactionHistory',
                request_serializer=org_dot_xrpl_dot_rpc_dot_v1_dot_get__account__transaction__history__pb2.GetAccountTransactionHistoryRequest.SerializeToString,
                response_deserializer=org_dot_xrpl_dot_rpc_dot_v1_dot_get__account__transaction__history__pb2.GetAccountTransactionHistoryResponse.FromString,
                )
        self.GetLedger = channel.unary_unary(
                '/org.xrpl.rpc.v1.XRPLedgerAPIService/GetLedger',
                request_serializer=org_dot_xrpl_dot_rpc_dot_v1_dot_get__ledger__pb2.GetLedgerRequest.SerializeToString,
                response_deserializer=org_dot_xrpl_dot_rpc_dot_v1_dot_get__ledger__pb2.GetLedgerResponse.FromString,
                )
        self.GetLedgerEntry = channel.unary_unary(
                '/org.xrpl.rpc.v1.XRPLedgerAPIService/GetLedgerEntry',
                request_serializer=org_dot_xrpl_dot_rpc_dot_v1_dot_get__ledger__entry__pb2.GetLedgerEntryRequest.SerializeToString,
                response_deserializer=org_dot_xrpl_dot_rpc_dot_v1_dot_get__ledger__entry__pb2.GetLedgerEntryResponse.FromString,
                )
        self.GetLedgerData = channel.unary_unary(
                '/org.xrpl.rpc.v1.XRPLedgerAPIService/GetLedgerData',
                request_serializer=org_dot_xrpl_dot_rpc_dot_v1_dot_get__ledger__data__pb2.GetLedgerDataRequest.SerializeToString,
                response_deserializer=org_dot_xrpl_dot_rpc_dot_v1_dot_get__ledger__data__pb2.GetLedgerDataResponse.FromString,
                )
        self.GetLedgerDiff = channel.unary_unary(
                '/org.xrpl.rpc.v1.XRPLedgerAPIService/GetLedgerDiff',
                request_serializer=org_dot_xrpl_dot_rpc_dot_v1_dot_get__ledger__diff__pb2.GetLedgerDiffRequest.SerializeToString,
                response_deserializer=org_dot_xrpl_dot_rpc_dot_v1_dot_get__ledger__diff__pb2.GetLedgerDiffResponse.FromString,
                )


class XRPLedgerAPIServiceServicer(object):
    """RPCs available to interact with the XRP Ledger.
    The gRPC API mimics the JSON API. Refer to xrpl.org for documentation
    """

    def GetAccountInfo(self, request, context):
        """Get account info for an account on the XRP Ledger.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFee(self, request, context):
        """Get the fee for a transaction on the XRP Ledger.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubmitTransaction(self, request, context):
        """Submit a signed transaction to the XRP Ledger.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransaction(self, request, context):
        """Get the status of a transaction
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAccountTransactionHistory(self, request, context):
        """Get all validated transactions associated with a given account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLedger(self, request, context):
        """///////////////////////////////////////////////////////////////////////////
        The below methods do not mimic the JSON API exactly, and are mostly binary

        Get a specific ledger, optionally including transactions and any modified,
        added or deleted ledger objects
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLedgerEntry(self, request, context):
        """Get a specific ledger object from a specific ledger
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLedgerData(self, request, context):
        """Iterate through all ledger objects in a specific ledger
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLedgerDiff(self, request, context):
        """Get all ledger objects that are different between the two specified
        ledgers. Note, this method has no JSON equivalent.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_XRPLedgerAPIServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetAccountInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccountInfo,
                    request_deserializer=org_dot_xrpl_dot_rpc_dot_v1_dot_get__account__info__pb2.GetAccountInfoRequest.FromString,
                    response_serializer=org_dot_xrpl_dot_rpc_dot_v1_dot_get__account__info__pb2.GetAccountInfoResponse.SerializeToString,
            ),
            'GetFee': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFee,
                    request_deserializer=org_dot_xrpl_dot_rpc_dot_v1_dot_get__fee__pb2.GetFeeRequest.FromString,
                    response_serializer=org_dot_xrpl_dot_rpc_dot_v1_dot_get__fee__pb2.GetFeeResponse.SerializeToString,
            ),
            'SubmitTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.SubmitTransaction,
                    request_deserializer=org_dot_xrpl_dot_rpc_dot_v1_dot_submit__pb2.SubmitTransactionRequest.FromString,
                    response_serializer=org_dot_xrpl_dot_rpc_dot_v1_dot_submit__pb2.SubmitTransactionResponse.SerializeToString,
            ),
            'GetTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransaction,
                    request_deserializer=org_dot_xrpl_dot_rpc_dot_v1_dot_get__transaction__pb2.GetTransactionRequest.FromString,
                    response_serializer=org_dot_xrpl_dot_rpc_dot_v1_dot_get__transaction__pb2.GetTransactionResponse.SerializeToString,
            ),
            'GetAccountTransactionHistory': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccountTransactionHistory,
                    request_deserializer=org_dot_xrpl_dot_rpc_dot_v1_dot_get__account__transaction__history__pb2.GetAccountTransactionHistoryRequest.FromString,
                    response_serializer=org_dot_xrpl_dot_rpc_dot_v1_dot_get__account__transaction__history__pb2.GetAccountTransactionHistoryResponse.SerializeToString,
            ),
            'GetLedger': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLedger,
                    request_deserializer=org_dot_xrpl_dot_rpc_dot_v1_dot_get__ledger__pb2.GetLedgerRequest.FromString,
                    response_serializer=org_dot_xrpl_dot_rpc_dot_v1_dot_get__ledger__pb2.GetLedgerResponse.SerializeToString,
            ),
            'GetLedgerEntry': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLedgerEntry,
                    request_deserializer=org_dot_xrpl_dot_rpc_dot_v1_dot_get__ledger__entry__pb2.GetLedgerEntryRequest.FromString,
                    response_serializer=org_dot_xrpl_dot_rpc_dot_v1_dot_get__ledger__entry__pb2.GetLedgerEntryResponse.SerializeToString,
            ),
            'GetLedgerData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLedgerData,
                    request_deserializer=org_dot_xrpl_dot_rpc_dot_v1_dot_get__ledger__data__pb2.GetLedgerDataRequest.FromString,
                    response_serializer=org_dot_xrpl_dot_rpc_dot_v1_dot_get__ledger__data__pb2.GetLedgerDataResponse.SerializeToString,
            ),
            'GetLedgerDiff': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLedgerDiff,
                    request_deserializer=org_dot_xrpl_dot_rpc_dot_v1_dot_get__ledger__diff__pb2.GetLedgerDiffRequest.FromString,
                    response_serializer=org_dot_xrpl_dot_rpc_dot_v1_dot_get__ledger__diff__pb2.GetLedgerDiffResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'org.xrpl.rpc.v1.XRPLedgerAPIService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class XRPLedgerAPIService(object):
    """RPCs available to interact with the XRP Ledger.
    The gRPC API mimics the JSON API. Refer to xrpl.org for documentation
    """

    @staticmethod
    def GetAccountInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.xrpl.rpc.v1.XRPLedgerAPIService/GetAccountInfo',
            org_dot_xrpl_dot_rpc_dot_v1_dot_get__account__info__pb2.GetAccountInfoRequest.SerializeToString,
            org_dot_xrpl_dot_rpc_dot_v1_dot_get__account__info__pb2.GetAccountInfoResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFee(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.xrpl.rpc.v1.XRPLedgerAPIService/GetFee',
            org_dot_xrpl_dot_rpc_dot_v1_dot_get__fee__pb2.GetFeeRequest.SerializeToString,
            org_dot_xrpl_dot_rpc_dot_v1_dot_get__fee__pb2.GetFeeResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SubmitTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.xrpl.rpc.v1.XRPLedgerAPIService/SubmitTransaction',
            org_dot_xrpl_dot_rpc_dot_v1_dot_submit__pb2.SubmitTransactionRequest.SerializeToString,
            org_dot_xrpl_dot_rpc_dot_v1_dot_submit__pb2.SubmitTransactionResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.xrpl.rpc.v1.XRPLedgerAPIService/GetTransaction',
            org_dot_xrpl_dot_rpc_dot_v1_dot_get__transaction__pb2.GetTransactionRequest.SerializeToString,
            org_dot_xrpl_dot_rpc_dot_v1_dot_get__transaction__pb2.GetTransactionResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAccountTransactionHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.xrpl.rpc.v1.XRPLedgerAPIService/GetAccountTransactionHistory',
            org_dot_xrpl_dot_rpc_dot_v1_dot_get__account__transaction__history__pb2.GetAccountTransactionHistoryRequest.SerializeToString,
            org_dot_xrpl_dot_rpc_dot_v1_dot_get__account__transaction__history__pb2.GetAccountTransactionHistoryResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLedger(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.xrpl.rpc.v1.XRPLedgerAPIService/GetLedger',
            org_dot_xrpl_dot_rpc_dot_v1_dot_get__ledger__pb2.GetLedgerRequest.SerializeToString,
            org_dot_xrpl_dot_rpc_dot_v1_dot_get__ledger__pb2.GetLedgerResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLedgerEntry(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.xrpl.rpc.v1.XRPLedgerAPIService/GetLedgerEntry',
            org_dot_xrpl_dot_rpc_dot_v1_dot_get__ledger__entry__pb2.GetLedgerEntryRequest.SerializeToString,
            org_dot_xrpl_dot_rpc_dot_v1_dot_get__ledger__entry__pb2.GetLedgerEntryResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLedgerData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.xrpl.rpc.v1.XRPLedgerAPIService/GetLedgerData',
            org_dot_xrpl_dot_rpc_dot_v1_dot_get__ledger__data__pb2.GetLedgerDataRequest.SerializeToString,
            org_dot_xrpl_dot_rpc_dot_v1_dot_get__ledger__data__pb2.GetLedgerDataResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLedgerDiff(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.xrpl.rpc.v1.XRPLedgerAPIService/GetLedgerDiff',
            org_dot_xrpl_dot_rpc_dot_v1_dot_get__ledger__diff__pb2.GetLedgerDiffRequest.SerializeToString,
            org_dot_xrpl_dot_rpc_dot_v1_dot_get__ledger__diff__pb2.GetLedgerDiffResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['xpring', 'xpring.algorithms', 'xpring.proto', 'xpring.proto.v1']

package_data = \
{'': ['*']}

install_requires = \
['dataclasses>=0.6.0,<0.7.0',
 'ecdsa>=0.15.0,<0.16.0',
 'grpcio>=1.24,<2.0',
 'protobuf>=3.0,<4.0',
 'pynacl>=1.3,<2.0',
 'typing_extensions>=3.7,<4.0']

extras_require = \
{'docs': ['sphinx>=1.8,<2.0',
          'sphinx-autobuild>=0.7.1,<0.8.0',
          'sphinx_rtd_theme>=0.4.3,<0.5.0',
          'toml>=0.10.0,<0.11.0'],
 'py': ['fastecdsa>=2.1.1,<3.0.0']}

setup_kwargs = {
    'name': 'xpring',
    'version': '0.6.2',
    'description': '',
    'long_description': '.. start-include\n\n======\nxpring\n======\n\nThe Xpring SDK for Python.\n\n.. image:: https://travis-ci.org/thejohnfreeman/xpring-py.svg?branch=master\n   :target: https://travis-ci.org/thejohnfreeman/xpring-py\n   :alt: Build status: Linux and OSX\n\n.. image:: https://ci.appveyor.com/api/projects/status/github/thejohnfreeman/xpring-py?branch=master&svg=true\n   :target: https://ci.appveyor.com/project/thejohnfreeman/xpring-py\n   :alt: Build status: Windows\n\n.. image:: https://readthedocs.org/projects/xpring-py/badge/?version=latest\n   :target: https://xpring-py.readthedocs.io/\n   :alt: Documentation status\n\n.. image:: https://img.shields.io/pypi/v/xpring.svg\n   :target: https://pypi.org/project/xpring/\n   :alt: Latest PyPI version\n\n.. image:: https://img.shields.io/pypi/pyversions/xpring.svg\n   :target: https://pypi.org/project/xpring/\n   :alt: Python versions supported\n\n\nInstall\n=======\n\n.. code-block:: shell\n\n   pip install xpring[py]\n\n\nAPI\n===\n\n------\nWallet\n------\n\nConstruct\n---------\n\nYou can construct a ``Wallet`` from its seed.\nIf you do not have your own wallet yet, you can `generate one with some free\nXRP on the testnet`__.\n\n.. __: https://xrpl.org/xrp-testnet-faucet.html\n\n.. code-block:: python\n\n   import xpring\n\n   seed = \'sEdSKaCy2JT7JaM7v95H9SxkhP9wS2r\'\n   wallet = xpring.Wallet.from_seed(seed)\n   print(wallet.private_key.hex())\n   # b4c4e046826bd26190d09715fc31f4e6a728204eadd112905b08b14b7f15c4f3\n   print(wallet.public_key.hex())\n   # ed01fa53fa5a7e77798f882ece20b1abc00bb358a9e55a202d0d0676bd0ce37a63\n   print(wallet.account_id.hex())\n   # d28b177e48d9a8d057e70f7e464b498367281b98\n   print(wallet.address)\n   # rLUEXYuLiQptky37CqLcm9USQpPiz5rkpD\n\n\nSign / Verify\n-------------\n\nA ``Wallet`` can sign and verify arbitrary bytes, but you\'ll generally\nwant to leave these low-level responsibilities to the ``Client``.\n\n.. code-block:: python\n\n   message = bytes.fromhex(\'DEADBEEF\')\n   signature = wallet.sign(message)\n   wallet.verify(message, signature)\n   # True\n\n\n------\nClient\n------\n\n``Client`` is the gateway to the XRP Ledger.\nIt is constructed with the URL of the gRPC service of a rippled_ server.\nIf you are running the server yourself,\nyou need to configure the ``[port_grpc]`` stanza in your configuration file.\nIn the example_ configuration file, it is commented_ out.\n\n.. _rippled: https://github.com/ripple/rippled\n.. _example: https://github.com/ripple/rippled/blob/develop/cfg/rippled-example.cfg\n.. _commented: https://github.com/ripple/rippled/blob/0c6d380780ae368a2236a2e8e3e42efa4a1d2b46/cfg/rippled-example.cfg#L1181-L1183\n\n.. code-block:: python\n\n   # url = \'main.xrp.xpring.io:50051\' # Mainnet\n   url = \'test.xrp.xpring.io:50051\' # Testnet\n   client = xpring.Client.from_url(url)\n\n\nAccount\n-------\n\n.. code-block:: python\n\n   >>> client.get_account(wallet.address)\n   account_data {\n     account {\n       value {\n         address: "rDuKotkyx18D5WqWCA4mVhRWK2YLqDFKaY"\n       }\n     }\n     balance {\n       value {\n         xrp_amount {\n           drops: 999999820\n         }\n       }\n     }\n     sequence: {\n       value: 10\n     }\n     flags {\n     }\n     owner_count {\n     }\n     previous_transaction_id {\n       value: b"..."\n     }\n     previous_transaction_ledger_sequence {\n       value: 4845872\n     }\n   }\n   ledger_index: 4869818\n\n\nFee\n---\n\n.. code-block:: python\n\n   >>> client.get_fee()\n   current_ledger_size: 6\n   fee {\n     base_fee {\n       drops: 10\n     }\n     median_fee {\n       drops: 5000\n     }\n     minimum_fee {\n       drops: 10\n     }\n     open_ledger_fee {\n       drops: 10\n     }\n   }\n   expected_ledger_size: 25\n   ledger_current_index: 4869844\n   levels {\n     median_level: 128000\n     minimum_level: 256\n     open_ledger_level: 256\n     reference_level: 256\n   }\n   max_queue_size: 2000\n\n\nSubmit\n------\n\n.. code-block:: python\n\n   >>> unsigned_transaction = {\n   ...     \'Account\': \'rDuKotkyx18D5WqWCA4mVhRWK2YLqDFKaY\',\n   ...     \'Amount\': \'10\',\n   ...     \'Destination\': \'rNJDvXkaBRwJYdeEcx9pchE2SecMkH3FLz\',\n   ...     \'Fee\': \'10\',\n   ...     \'Flags\': 0x80000000,\n   ...     \'Sequence\': 9,\n   ...     \'TransactionType\': \'Payment\'\n   ... }\n   >>> signed_transaction = wallet.sign_transaction(unsigned_transaction)\n   >>> client.submit(signed_transaction)\n   engine_result {\n     result_type: RESULT_TYPE_TES\n     result: "tesSUCCESS"\n   }\n   engine_result_message: "The transaction was applied. Only final in a validated ledger."\n   hash: b"..."\n   >>> client.submit(signed_transaction)\n   engine_result {\n     result_type: RESULT_TYPE_TEF\n     result: "tefPAST_SEQ"\n   }\n   engine_result_code: -190\n   engine_result_message: "This sequence number has already passed."\n   hash: b"..."\n\n\nTransaction\n-----------\n\n.. code-block:: python\n\n   >>> txid = bytes.fromhex(signed_transaction[\'hash\'])\n   >>> client.get_transaction(txid)\n   transaction {\n     account {\n       value {\n         address: "rDuKotkyx18D5WqWCA4mVhRWK2YLqDFKaY"\n       }\n     }\n     fee {\n       drops: 10\n     }\n     sequence {\n       value: 10\n     }\n     payment {\n       amount {\n         value {\n           xrp_amount {\n             drops: 10\n           }\n         }\n       }\n       destination {\n         value {\n           address: "rNJDvXkaBRwJYdeEcx9pchE2SecMkH3FLz"\n         }\n       }\n     }\n     signing_public_key {\n       value: b"..."\n     }\n     transaction_signature {\n       value: b"..."\n     }\n     flags {\n       value: 2147483648\n     }\n   }\n   ledger_index: 5124377\n   hash: b"..."\n   validated: true\n   meta {\n     transaction_index: 1\n     transaction_result {\n       result_type: RESULT_TYPE_TES\n       result: "tesSUCCESS"\n     }\n     affected_nodes {\n       ledger_entry_type: LEDGER_ENTRY_TYPE_ACCOUNT_ROOT\n       ledger_index: b"..."\n       modified_node {\n         final_fields {\n           account_root {\n             account {\n               value {\n                 address: "rNJDvXkaBRwJYdeEcx9pchE2SecMkH3FLz"\n               }\n             }\n             balance {\n               value {\n                 xrp_amount {\n                   drops: 1000000100\n                 }\n               }\n             }\n             sequence {\n               value: 1\n             }\n             flags {\n             }\n             owner_count {\n             }\n           }\n         }\n         previous_fields {\n           account_root {\n             balance {\n               value {\n                 xrp_amount {\n                   drops: 1000000090\n                 }\n               }\n             }\n           }\n         }\n         previous_transaction_id {\n           value: b"..."\n         }\n         previous_transaction_ledger_sequence {\n           value: 4845872\n         }\n       }\n     }\n     affected_nodes {\n       ledger_entry_type: LEDGER_ENTRY_TYPE_ACCOUNT_ROOT\n       ledger_index: b"..."\n       modified_node {\n         final_fields {\n           account_root {\n             account {\n               value {\n                 address: "rDuKotkyx18D5WqWCA4mVhRWK2YLqDFKaY"\n               }\n             }\n             balance {\n               value {\n                 xrp_amount {\n                   drops: 999999800\n                 }\n               }\n             }\n             sequence {\n               value: 11\n             }\n             flags {\n             }\n             owner_count {\n             }\n           }\n         }\n         previous_fields {\n           account_root {\n             balance {\n               value {\n                 xrp_amount {\n                   drops: 999999820\n                 }\n               }\n             }\n             sequence {\n               value: 10\n             }\n           }\n         }\n         previous_transaction_id {\n           value: b"..."\n         }\n         previous_transaction_ledger_sequence {\n           value: 4845872\n         }\n       }\n     }\n     delivered_amount {\n       value {\n         xrp_amount {\n           drops: 10\n         }\n       }\n     }\n   }\n   date {\n     value: 636581642\n   }\n\n\n.. end-include\n',
    'author': 'John Freeman',
    'author_email': 'jfreeman@ripple.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/thejohnfreeman/xpring-py/',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '>=3.6',
}


setup(**setup_kwargs)
